#!/bin/bash
#
# simple-sync-phone:bin/api/find-port-on-network-api.sh
#
function __find_port_on_ipv4_network_do_scan_nmap__ {
  local -r _ip_="$1"
  local -r _len_="$2"
  local -r _port_="$3"

  (
    [ "${__DEBUG_NMAP__:-}" = 'true' ] && set -x
    nmap -n -T4 -oG - -p "${_port_}" "${_ip_}/${_len_}"
  ) || return $?
}

function __find_port_on_ipv4_network_do_scan__ {
  local -r _ip_="$1"
  local -r _len_="$2"
  local -r _port_="$3"

  echoinfo "${FUNCNAME[0]}( '${_ip_}/${_len_}:${_port_}' )"

  __find_port_on_ipv4_network_do_scan_nmap__ "${_ip_}" "${_len_}" "${_port_}" |
    sed -E -e "/${_port_}\/open\/tcp/!d" -e 's,^.*:[[:blank:]]([0-9.]+)[[:blank:]].*$,\1,g' |
    sort -n |
    uniq || return $?
}

function __find_port_on_ipv4_network_entry__ {
  local -r ipv4_json="$1"
  local -r port="$2"

  local ip=
  ip="$( jq -r '.local' <<<"${ipv4_json}" )" || return $?

  local len=
  len="$( jq -r '.prefixlen' <<<"${ipv4_json}" )" || return $?

  if [ "${len}" -eq 24 ] ; then
    __find_port_on_ipv4_network_do_scan__ "${ip}" "${len}" "${port}" || return $?
  else
    echowarn "Skip network for '${ip}/${len}. (Length not supported)"
  fi
}

function find_port_on_ipv4_network {
  local -ri port="$1"

  local ipv4_networks=
  ipv4_networks="$(
    ip -4 --json addr show |
    jq -c 'map( select( .flags | index("LOOPBACK") | not ) | select( .flags | index( "UP") ) | .addr_info[] | { local, prefixlen } )[]'
  )" || return $?

  local ipv4_network=
  while read -r ipv4_network ; do
    if [ -n "${ipv4_network}" ] ; then
      __find_port_on_ipv4_network_entry__ "${ipv4_network}" "${port}" || return $?
    fi
  done <<<"${ipv4_networks}"
}
