#!/bin/bash
#
# simple-sync-phone:bin/api/rsync-to-phone-api.sh
#
declare -gx RSYNC_TO_PHONE_REMOTE_USER='user'

function rsync_to_phone {
  local -r ip="$1"
  local -r port="$2"
  local -r source="$3"
  local -r destination="$4"

  if [ ! -e "${source}" ] ; then
    echo "File not found: '${source}'."
    return 100
  fi

  local -a rsync_opts=()
  rsync_opts+=('--compress')
  rsync_opts+=('--copy-links')
  rsync_opts+=('--progress')
  rsync_opts+=('--update')
  rsync_opts+=('--verbose')

  local fixed_source=
  local fixed_destination=
  if [ -f "${source}" ] ; then
    echoinfo "Synchronize file: '${source}'"

    fixed_source="${source}"
    fixed_destination="${destination}"
  elif [ -d "${source}" ] ; then
    echoinfo "Synchronize directory: '${source}'"

    rsync_opts+=('--delete')
    rsync_opts+=('--recursive')

    fixed_source='.'
    fixed_destination="$( dirname "${destination}" )/$( basename "${destination}" )/"
  else
    echo "Can't handle: '${source}'"
    return 100
  fi
  (
    [ "${VERBOSE:-}" = "true" ] && set -x
    if [ "${fixed_source}" = '.' ] ; then
      cd "${source}" || return $?
    fi
    rsync "${rsync_opts[@]}" -e "ssh -p '${port}'" "${fixed_source}" "${RSYNC_TO_PHONE_REMOTE_USER}@${ip}:${fixed_destination}"
  ) || return $?
}
